@@ -13,7 +13,10 @@ __title__ = 'qualichat'
 __author__ = 'Ernest Manheim'
 __license__ = 'MIT'
 __copyright__ = 'Copyright 2021-present Ernest Manheim'
-__version__ = '1.3.0'
+__version__ = '1.3.8'
+
+
+__all__ = ('load_chats',)
 
 
 from typing import NamedTuple
@@ -28,4 +31,4 @@ class VersionInfo(NamedTuple):
     releaselevel: str
     serial: int
 
-version_info = VersionInfo(major=1, minor=3, micro=0, releaselevel='stable', serial=0)
+version_info = VersionInfo(1, 3, 8, 'stable', 0)
